NativeAd class

Inheritance

Constructors

NativeAd({Key? key, String placementId = NativeAd.testPlacementId, NativeAdListener? listener, required NativeAdType adType, NativeBannerAdSize bannerAdSize = NativeBannerAdSize.HEIGHT_50, double width = double.infinity, double height = 250, Color? backgroundColor, Color? titleColor, Color? descriptionColor, Color? labelColor, Color? buttonColor, Color? buttonTitleColor, Color? buttonBorderColor, bool isMediaCover = false, bool keepAlive = false, bool keepExpandedWhileLoading = true, int expandAnimationDuraion = 0})
This widget can be used to display customizable native ads and native banner ads.

Properties

adType → NativeAdType
Choose between NativeAdType.NATIVE_AD and NativeAdType.NATIVE_BANNER_AD
final
backgroundColor → Color?
This defines the background color of the Native Ad.
final
bannerAdSize → NativeBannerAdSize
If adType is NativeAdType.NATIVE_BANNER_AD you can choose between three predefined Ad sizes.
final
buttonBorderColor → Color?
This defines the button border color of the Native Ad.
final
buttonColor → Color?
This defines the button color of the Native Ad.
final
buttonTitleColor → Color?
This defines the button text color of the Native Ad.
final
descriptionColor → Color?
This defines the description text color of the Native Ad.
final
expandAnimationDuraion → int
Expand animation duration in milliseconds
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
Recommended width is between 250-500 for Native Ads. Native Banner Ad height is predefined in bannerAdSize and cannot be changed through this parameter.
final
isMediaCover → bool
final
keepAlive → bool
This defines if the ad view to be kept alive.
final
keepExpandedWhileLoading → bool
This defines if the ad view should be collapsed while loading
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelColor → Color?
This defines the button color of the Native Ad.
final
listener → NativeAdListener?
Native Ad listener.
final
placementId → String
Replace the default one with your placement ID for the release build.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titleColor → Color?
This defines the title text color of the Native Ad.
final
width → double
Recommended width is between 280-500 for Native Ads. You can use double.infinity as the width to match the parent widget width.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _NativeAdState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

testPlacementId → const String